"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Rx_1 = require("rxjs/Rx");
var socketMessage_1 = require("./socketMessage");
var helpers_1 = require("./helpers");
function makeSubscriberMapObservable(subscribers) {
    return new Rx_1.Observable(function (sub) {
        var id = helpers_1.generateRandomId();
        subscribers.set(id, sub);
        return function () {
            subscribers.delete(id);
        };
    });
}
exports.makeSubscriberMapObservable = makeSubscriberMapObservable;
function complete(subscribers) {
    iterableForEach(subscribers.values(), function (sub) { return sub.complete(); });
}
exports.complete = complete;
function sendData(subscribers, data) {
    iterableForEach(subscribers.values(), function (sub) { return sub.next(data); });
}
exports.sendData = sendData;
function sendMessageIfPrefixed(prefix, serialData, subscribers) {
    if (hasPrefix(prefix, serialData)) {
        var message = socketMessage_1.deserializeMessage(serialData.substring(prefix.length).trim());
        if (message) {
            sendData(subscribers, message);
        }
    }
}
exports.sendMessageIfPrefixed = sendMessageIfPrefixed;
function iterableForEach(iterator, process) {
    var _a = iterator.next(), done = _a.done, value = _a.value;
    while (!done) {
        process(value);
        var item = iterator.next();
        done = item.done;
        value = item.value;
    }
}
exports.iterableForEach = iterableForEach;
function iterableToArray(iterator) {
    var output = [];
    iterableForEach(iterator, function (item) { return output.push(item); });
    return output;
}
exports.iterableToArray = iterableToArray;
function hasPrefix(prefix, data) {
    for (var i = 0; i < prefix.length; i++) {
        if (data[i] !== prefix[i]) {
            return false;
        }
    }
    return true;
}
