import { connection as WebsocketConnection } from 'websocket';
import { Observable } from 'rxjs/Rx';
import { SocketMessage } from './socketMessage';
export declare type MergeStrategy = 'replace' | 'upsert' | 'append' | 'prepend';
export interface SubscriptionTracker {
    registerSubscription: (connection: StockingsConnection, type: string) => void;
    unregisterSubscription: (connection: StockingsConnection, type: string) => void;
}
export interface Transaction {
    transactionId: string;
    subscriptions: TransactionSubscription[];
}
export interface TransactionSubscription {
    type: string;
    mergeStrategy?: MergeStrategy;
    upsertKey?: string;
}
export declare class StockingsConnection {
    readonly dataObservable: Observable<SocketMessage<any>>;
    readonly controlObservable: Observable<SocketMessage<any>>;
    readonly closeObservable: Observable<void>;
    private _connection;
    private _clientId;
    private readonly _dataSubscribers;
    private readonly _controlSubscribers;
    private readonly _closeSubscribers;
    private readonly _subscriptions;
    private readonly _transactions;
    private readonly _tracker;
    constructor(connection: WebsocketConnection, tracker: SubscriptionTracker);
    getId(): string;
    getClientAddress(): string;
    generateTransactionId(): string;
    sendData<T>(type: string, payload: T): void;
    sendControl<T>(type: string, payload: T): void;
    listenData<T>(type: string): Observable<T>;
    listenControl<T>(type: string): Observable<T>;
    addSubscription(type: string, transactionId: string, mergeStrategy?: MergeStrategy, upsertKey?: string): number;
    removeSubscriptions(transactionId: string): void;
    getSubscriptionHeader(transactionId: string): string;
    getSubscriptions(transactionId: string): string[];
    getAllSubscriptions(): string[];
    addSubscriptionsFrom(other: StockingsConnection): void;
    close(): void;
    private _removeSubscription(type);
    private _buildTransaction(transactionId);
}
