"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var jwt = require("jsonwebtoken");
function makeDecoder(algorithm, decryptionKey) {
    return function decode(clientToken) {
        return new Promise(function (res, rej) {
            if (clientToken) {
                jwt.verify(clientToken, decryptionKey, { algorithms: [algorithm], ignoreExpiration: true, subject: 'stockings' }, function (err, decoded) {
                    if (err) {
                        return rej(err);
                    }
                    if (!decoded || !decoded.clientId || !decoded.address) {
                        return rej('Malformed client token');
                    }
                    res(decoded);
                });
            }
            else {
                res(null);
            }
        });
    };
}
exports.makeDecoder = makeDecoder;
function makeEncoder(algorithm, encryptionKey) {
    return function encode(clientId, address) {
        return new Promise(function (res, rej) {
            if (clientId === null || clientId === undefined) {
                return rej('Parameter clientId was not supplied correctly.');
            }
            var payload = {
                clientId: clientId,
                address: address
            };
            jwt.sign(payload, encryptionKey, { algorithm: algorithm, expiresIn: '30m', subject: 'stockings' }, function (err, data) {
                if (err) {
                    return rej(err);
                }
                res(data);
            });
        });
    };
}
exports.makeEncoder = makeEncoder;
function isAlgorithmAsymmetric(algorithm) {
    return algorithm.toUpperCase().indexOf('RS') === 0;
}
exports.isAlgorithmAsymmetric = isAlgorithmAsymmetric;
